@@ -7,7 +7,7 @@ from typing import BinaryIO
 from PIL.Image import Image as _Image
 
 from .Keys import Keys
-from .MixIns import *
+from ..nameof import nameof
 
 
 
@@ -57,19 +57,16 @@ def RaiseKeyError(key, d: Dict): raise KeyError(f'{key} not in {d.keys()}')
 
 class BaseModel(object):
     def Clone(self): return _copy.deepcopy(self)
-    def ToString(self) -> str:
-        # try: return f'<{self.__class__.__qualname__} Object. State: {self.__dict__}>'
-        # except AttributeError: return f'<{self.__class__.__name__} Object. State: {self.__dict__}>'
-        try:
-            return f'<{self.__class__.__qualname__} Object() [ {self.ToJsonString()} ]'
-        except AttributeError:
-            return f'<{self.__class__.__name__} Object() [ {self.ToJsonString()} ]'
+    def ToString(self) -> str: return f'<{nameof(self)} Object() {self.ToJsonString()}>'
+    @property
+    def __class_name__(self) -> str: return nameof(self)
+
+
 
     @classmethod
     def Parse(cls, d): raise NotImplementedError()
-
     @classmethod
-    def FromJson(cls, string: Union[str, bytes, bytearray], **kwargs): return cls.Parse(_loads(string, **kwargs))
+    def FromJson(cls, string: Union[str, bytes, bytearray], **kwargs): raise NotImplementedError()
 
     def ToJsonString(self, indent=4, ) -> str: return _dumps(self, indent=indent, default=self._serialize)
 
@@ -114,15 +111,19 @@ class BaseModel(object):
             else: d[key] = value
         return d
 
+
 class BaseObjectModel(BaseModel):
     @classmethod
     def Parse(cls, d): raise NotImplementedError()
+    @classmethod
+    def FromJson(cls, string: Union[str, bytes, bytearray], **kwargs): raise NotImplementedError()
 
     def _Filter(self, func: callable): raise NotImplementedError()
     def enumerate(self): raise NotImplementedError()
     def Count(self) -> int: raise NotImplementedError()
     def Empty(self) -> bool: raise NotImplementedError()
 
+
 class BaseListModel(list, BaseObjectModel, List[_T]):
     def __init__(self, source: Union[List, Iterable] = None):
         super().__init__(source or [])
@@ -165,9 +166,10 @@ class BaseListModel(list, BaseObjectModel, List[_T]):
         throw(d, list)
 
     @classmethod
-    def Create(cls, *args: _T):
-        return cls(args)
+    def Create(cls, *args: _T): return cls(args)
 
+    @classmethod
+    def FromJson(cls, string: Union[str, bytes, bytearray], **kwargs): return cls.Parse(_loads(string, **kwargs))
 
 
 class BaseSetModel(set, BaseObjectModel, Set[_T]):
@@ -204,9 +206,10 @@ class BaseSetModel(set, BaseObjectModel, Set[_T]):
         throw(d, list)
 
     @classmethod
-    def Create(cls, *args: _T):
-        return cls(args)
+    def Create(cls, *args: _T): return cls(args)
 
+    @classmethod
+    def FromJson(cls, string: Union[str, bytes, bytearray], **kwargs): return cls.Parse(_loads(string, **kwargs))
 
 
 class BaseDictModel(dict, BaseObjectModel, Dict[_KT, _VT]):
@@ -215,6 +218,7 @@ class BaseDictModel(dict, BaseObjectModel, Dict[_KT, _VT]):
         else: super().__init__(**kwargs)
     def __str__(self): return self.ToString()
 
+    # def __deepcopy__(self): return super(BaseDictModel, self).__deepcopy__()
     def __delitem__(self, item: Union[_KT, _VT]): return super().__delitem__(item)
     def __contains__(self, item: Union[_KT, _VT]): return super().__contains__(item)
     def __setitem__(self, key: _KT, value: _VT): return super().__setitem__(key, value)
@@ -245,13 +249,13 @@ class BaseDictModel(dict, BaseObjectModel, Dict[_KT, _VT]):
         throw(d, dict)
 
     @classmethod
-    def Create(cls, **kwargs: _VT):
-        return cls(kwargs)
+    def Create(cls, **kwargs: _VT): return cls(kwargs)
+
+    @classmethod
+    def FromJson(cls, string: Union[str, bytes, bytearray], **kwargs): return cls.Parse(_loads(string, **kwargs))
 
 
 
-
-# noinspection DuplicatedCode
 class Size(BaseDictModel[str, int]):
     __slots__ = []
     @property
@@ -351,7 +355,6 @@ class Ratios(Size):
 
 
 
-# noinspection DuplicatedCode
 class Point(BaseDictModel[str, int]):
     __slots__ = []
     @property
@@ -420,6 +423,7 @@ class Point(BaseDictModel[str, int]):
 
         throw(d, dict)
 
+
 class PlacePosition(Point):
     """ tkinter uses top boundary as x axis. """
     def Right(self, amount: int):
