@@ -23,7 +23,9 @@ from ..Events import Bindings
 from ...Files import FilePath
 from ...Images import *
 from ...Json import Size
+from ...Models import URL
 from ...debug import pp
+from ...nameof import nameof
 
 
 
@@ -395,6 +397,8 @@ class BaseTkinterWidget(tk.Widget, ABC):
         """ this is called just before widget disappears. override to implement desired effects """
         pass
 
+    @property
+    def __class_name__(self) -> str: return nameof(self)
 
 class BaseTextTkinterWidget(BaseTkinterWidget):
     _txt: tk.StringVar
@@ -498,12 +502,6 @@ class CurrentValue(CallWrapper):
 
 # ------------------------------------------------------------------------------------------
 
-class URL(str):
-    """ Any HTTP link """
-    def __init__(self, url: str):
-        if not isinstance(url, str): url = str(url)
-        if not url.lower().strip().startswith('http'): raise ValueError(f'passed url is not a link: "{url}"')
-        super().__init__(url)
 
 class CommandMixin:
     _cmd: CallWrapper
@@ -563,7 +561,7 @@ class ImageMixin:
 
 
     def SetImage(self, data: Union[str, bytes, Enum, FilePath, URL, PhotoImage], WidthMax: int = None, HeightMax: int = None):
-        if data is None: return self.configure(image=None)
+        if data is None: return self._setImage(None)
 
         if isinstance(data, Enum): data = data.value
 
@@ -593,7 +591,7 @@ class ImageMixin:
             img.Resize()
             return self._setImage(img.ToPhotoImage(master=self))
 
-    def _setImage(self, img: PhotoImage):
+    def _setImage(self, img: Optional[PhotoImage]):
         self.update_idletasks()
         self._IMG = img
         self.configure(image=self._IMG)
